import 'package:flutter/material.dart';
import 'package:iot_manager_grpc_api/pb/serverManager.pb.dart';
import 'package:openiothub_api/openiothub_api.dart';
import 'package:openiothub_common_pages/commPages/serverInfo.dart';
import 'package:openiothub_constants/constants/Constants.dart';

class ServerPages extends StatefulWidget {
  ServerPages({Key key, this.title}) : super(key: key);

  final String title;

  @override
  createState() => ServerPagesState();
}

class ServerPagesState extends State<ServerPages> {
  List<ServerInfo> _availableServerList = [];

  @override
  Future<void> initState() {
    _listMyServers();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final tiles = _availableServerList.map(
          (pair) {
        var listItemContent = Padding(
          padding: const EdgeInsets.fromLTRB(10.0, 15.0, 10.0, 15.0),
          child: Row(
            children: <Widget>[
              Padding(
                padding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
                child: Icon(Icons.send_rounded),
              ),
              Expanded(
                  child: Text(
                    "${pair.name}(${pair.serverHost})",
                    style: Constants.titleTextStyle,
                  )),
              Constants.rightArrowIcon
            ],
          ),
        );
        return InkWell(
          onTap: () {
            Navigator.of(context).push(MaterialPageRoute(builder: (context) {
              return ServerInfoPage(serverInfo: pair);
            }));
          },
          child: listItemContent,
        );
      },
    );
    final divided = ListTile.divideTiles(
      context: context,
      tiles: tiles,
    ).toList();
    return Scaffold(
        appBar: AppBar(
          title: Text("选择本网关需要连接的服务器"),
          actions: <Widget>[
            IconButton(
                icon: Icon(
                  Icons.refresh,
                  color: Colors.white,
                ),
                onPressed: () {
                  //刷新端口列表
                  _listMyServers();
                }),],
        ),
        body: ListView(
          children: divided,
        ));
  }

  Future<void> _listMyServers() async {
    ServerInfoList serverInfoList = await ServerManager.GetAllMyServers();
    setState(() {
      _availableServerList = serverInfoList.serverInfoList;
    });
  }
}
